@@ -3,7 +3,7 @@
 # Published under New BSD License, see LICENSE.txt for details.
 #
 
-import re, sys, logging, time
+import re, sys, logging, time, types
 
 from .util import Undef
 
@@ -562,10 +562,15 @@ class Calling(Rule):
             rule, args = rule
 
         ctx('*RULE*', rule)
+        method = getattr(P.grammar, rule)
+
+        if isinstance(method, types.UnboundMethodType):
+            method = method.__func__
+
         if args is None:
-            mob = getattr(P.grammar, rule)(P, s, start, end)
+            mob = method(P, s=s, start=start, end=end)
         else:
-            mob = getattr(P.grammar, rule)(P, s, start, end, args)
+            mob = method(P, s=s, start=start, end=end, args=args)
 
         if isinstance(mob, MatchObject):
             yield mob
